@@ -87,27 +87,30 @@ new LambdaToSqs(this, "test-lambda-sqs-stack", new LambdaToSqsProps.Builder()
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|An optional, existing Lambda function to be used instead of the default function. Providing both this and `lambdaFunctionProps` will cause an error.|
-|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|Optional user-provided properties to override the default properties for the Lambda function. |
-|existingQueueObj?|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.Queue.html)|An optional, existing SQS queue to be used instead of the default queue. Providing both this and `queueProps` will cause an error.|
-|queueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.QueueProps.html)|Optional user-provided properties to override the default properties for the SQS queue.|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|An optional, existing Lambda function to be used instead of the default function. Providing both this and `lambdaFunctionProps` will cause an error.|
+|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.FunctionProps.html)|Optional user-provided properties to override the default properties for the Lambda function. |
+|existingQueueObj?|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.Queue.html)|An optional, existing SQS queue to be used instead of the default queue. Providing both this and `queueProps` will cause an error.|
+|queueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.QueueProps.html)|Optional user-provided properties to override the default properties for the SQS queue.|
 |enableQueuePurging?|`boolean`|Whether to grant additional permissions to the Lambda function enabling it to purge the SQS queue. Defaults to `false`.|
 |deployDeadLetterQueue?|`boolean`|Whether to create a secondary queue to be used as a dead letter queue. Defaults to `true`.|
-|deadLetterQueueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.QueueProps.html)|Optional user-provided props to override the default props for the dead letter queue. Only used if the `deployDeadLetterQueue` property is set to true.|
+|deadLetterQueueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.QueueProps.html)|Optional user-provided props to override the default props for the dead letter queue. Only used if the `deployDeadLetterQueue` property is set to true.|
 |maxReceiveCount?|`number`|The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Defaults to `15`.|
-|existingVpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.IVpc.html)|An optional, existing VPC into which this pattern should be deployed. When deployed in a VPC, the Lambda function will use ENIs in the VPC to access network resources and an Interface Endpoint will be created in the VPC for Amazon SQS. If an existing VPC is provided, the `deployVpc` property cannot be `true`. This uses `ec2.IVpc` to allow clients to supply VPCs that exist outside the stack using the [`ec2.Vpc.fromLookup()`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.Vpc.html#static-fromwbrlookupscope-id-options) method.|
-|vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.VpcProps.html)|Optional user-provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overrriden. If `deployVpc` is not `true` then this property will be ignored.|
+|existingVpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.IVpc.html)|An optional, existing VPC into which this pattern should be deployed. When deployed in a VPC, the Lambda function will use ENIs in the VPC to access network resources and an Interface Endpoint will be created in the VPC for Amazon SQS. If an existing VPC is provided, the `deployVpc` property cannot be `true`. This uses `ec2.IVpc` to allow clients to supply VPCs that exist outside the stack using the [`ec2.Vpc.fromLookup()`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.Vpc.html#static-fromwbrlookupscope-id-options) method.|
+|vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.VpcProps.html)|Optional user-provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overrriden. If `deployVpc` is not `true` then this property will be ignored.|
 |deployVpc?|`boolean`|Whether to create a new VPC based on `vpcProps` into which to deploy this pattern. Setting this to true will deploy the minimal, most private VPC to run the pattern:<ul><li> One isolated subnet in each Availability Zone used by the CDK program</li><li>`enableDnsHostnames` and `enableDnsSupport` will both be set to true</li></ul>If this property is `true` then `existingVpc` cannot be specified. Defaults to `false`.|
 |queueEnvironmentVariableName?|`string`|Optional Name for the Lambda function environment variable set to the URL of the queue. Default: SQS_QUEUE_URL |
+|enableEncryptionWithCustomerManagedKey?|`boolean`|If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps.|
+|encryptionKey?|[`kms.Key`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html)|An optional, imported encryption key to encrypt the SQS Queue with.|
+|encryptionKeyProps?|[`kms.KeyProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html#construct-props)|Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS queue with.|
 
 ## Pattern Properties
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Returns an instance of the Lambda function created by the pattern.|
-|sqsQueue|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.Queue.html)|Returns an instance of the SQS queue created by the pattern. |
-|deadLetterQueue?|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.Queue.html)|Returns an instance of the dead letter queue created by the pattern, if one is deployed.|
-|vpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.IVpc.html)|Returns an interface on the VPC used by the pattern (if any). This may be a VPC created by the pattern or the VPC supplied to the pattern constructor.|
+|lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Returns an instance of the Lambda function created by the pattern.|
+|sqsQueue|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.Queue.html)|Returns an instance of the SQS queue created by the pattern. |
+|deadLetterQueue?|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.Queue.html)|Returns an instance of the dead letter queue created by the pattern, if one is deployed.|
+|vpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.IVpc.html)|Returns an interface on the VPC used by the pattern (if any). This may be a VPC created by the pattern or the VPC supplied to the pattern constructor.|
 
 ## Default settings
 
@@ -154,6 +157,7 @@ from typeguard import check_type
 from ._jsii import *
 
 import aws_cdk.aws_ec2
+import aws_cdk.aws_kms
 import aws_cdk.aws_lambda
 import aws_cdk.aws_sqs
 import constructs
@@ -176,7 +180,10 @@ class LambdaToSqs(
         dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         deploy_vpc: typing.Optional[builtins.bool] = None,
+        enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
         enable_queue_purging: typing.Optional[builtins.bool] = None,
+        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
@@ -192,7 +199,10 @@ class LambdaToSqs(
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
         :param deploy_dead_letter_queue: Whether to deploy a secondary queue to be used as a dead letter queue. Default: - true.
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
+        :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps. Default: - False if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
         :param enable_queue_purging: Whether to grant additional permissions to the Lambda function enabling it to purge the SQS queue. Default: - "false", disabled by default.
+        :param encryption_key: An optional, imported encryption key to encrypt the SQS Queue with. Default: - None
+        :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS Queue with. Default: - None
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param existing_queue_obj: Existing instance of SQS queue object, Providing both this and queueProps will cause an error. Default: - Default props are used
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
@@ -207,14 +217,38 @@ class LambdaToSqs(
         :summary: Constructs a new instance of the LambdaToSqs class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaToSqs.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+                deploy_vpc: typing.Optional[builtins.bool] = None,
+                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+                enable_queue_purging: typing.Optional[builtins.bool] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
+                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
+                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+                max_receive_count: typing.Optional[jsii.Number] = None,
+                queue_environment_variable_name: typing.Optional[builtins.str] = None,
+                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LambdaToSqsProps(
             dead_letter_queue_props=dead_letter_queue_props,
             deploy_dead_letter_queue=deploy_dead_letter_queue,
             deploy_vpc=deploy_vpc,
+            enable_encryption_with_customer_managed_key=enable_encryption_with_customer_managed_key,
             enable_queue_purging=enable_queue_purging,
+            encryption_key=encryption_key,
+            encryption_key_props=encryption_key_props,
             existing_lambda_obj=existing_lambda_obj,
             existing_queue_obj=existing_queue_obj,
             existing_vpc=existing_vpc,
@@ -227,22 +261,22 @@ class LambdaToSqs(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="sqsQueue")
     def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
         return typing.cast(aws_cdk.aws_sqs.Queue, jsii.get(self, "sqsQueue"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="deadLetterQueue")
     def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
         return typing.cast(typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue], jsii.get(self, "deadLetterQueue"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
         return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], jsii.get(self, "vpc"))
@@ -255,7 +289,10 @@ class LambdaToSqs(
         "dead_letter_queue_props": "deadLetterQueueProps",
         "deploy_dead_letter_queue": "deployDeadLetterQueue",
         "deploy_vpc": "deployVpc",
+        "enable_encryption_with_customer_managed_key": "enableEncryptionWithCustomerManagedKey",
         "enable_queue_purging": "enableQueuePurging",
+        "encryption_key": "encryptionKey",
+        "encryption_key_props": "encryptionKeyProps",
         "existing_lambda_obj": "existingLambdaObj",
         "existing_queue_obj": "existingQueueObj",
         "existing_vpc": "existingVpc",
@@ -273,7 +310,10 @@ class LambdaToSqsProps:
         dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         deploy_vpc: typing.Optional[builtins.bool] = None,
+        enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
         enable_queue_purging: typing.Optional[builtins.bool] = None,
+        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
@@ -287,7 +327,10 @@ class LambdaToSqsProps:
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
         :param deploy_dead_letter_queue: Whether to deploy a secondary queue to be used as a dead letter queue. Default: - true.
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
+        :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps. Default: - False if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
         :param enable_queue_purging: Whether to grant additional permissions to the Lambda function enabling it to purge the SQS queue. Default: - "false", disabled by default.
+        :param encryption_key: An optional, imported encryption key to encrypt the SQS Queue with. Default: - None
+        :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS Queue with. Default: - None
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param existing_queue_obj: Existing instance of SQS queue object, Providing both this and queueProps will cause an error. Default: - Default props are used
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
@@ -301,6 +344,8 @@ class LambdaToSqsProps:
         '''
         if isinstance(dead_letter_queue_props, dict):
             dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
+        if isinstance(encryption_key_props, dict):
+            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(queue_props, dict):
@@ -308,11 +353,33 @@ class LambdaToSqsProps:
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaToSqsProps.__init__)
+            def stub(
+                *,
+                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+                deploy_vpc: typing.Optional[builtins.bool] = None,
+                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+                enable_queue_purging: typing.Optional[builtins.bool] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
+                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
+                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+                max_receive_count: typing.Optional[jsii.Number] = None,
+                queue_environment_variable_name: typing.Optional[builtins.str] = None,
+                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument dead_letter_queue_props", value=dead_letter_queue_props, expected_type=type_hints["dead_letter_queue_props"])
             check_type(argname="argument deploy_dead_letter_queue", value=deploy_dead_letter_queue, expected_type=type_hints["deploy_dead_letter_queue"])
             check_type(argname="argument deploy_vpc", value=deploy_vpc, expected_type=type_hints["deploy_vpc"])
+            check_type(argname="argument enable_encryption_with_customer_managed_key", value=enable_encryption_with_customer_managed_key, expected_type=type_hints["enable_encryption_with_customer_managed_key"])
             check_type(argname="argument enable_queue_purging", value=enable_queue_purging, expected_type=type_hints["enable_queue_purging"])
+            check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
+            check_type(argname="argument encryption_key_props", value=encryption_key_props, expected_type=type_hints["encryption_key_props"])
             check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
             check_type(argname="argument existing_queue_obj", value=existing_queue_obj, expected_type=type_hints["existing_queue_obj"])
             check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
@@ -328,8 +395,14 @@ class LambdaToSqsProps:
             self._values["deploy_dead_letter_queue"] = deploy_dead_letter_queue
         if deploy_vpc is not None:
             self._values["deploy_vpc"] = deploy_vpc
+        if enable_encryption_with_customer_managed_key is not None:
+            self._values["enable_encryption_with_customer_managed_key"] = enable_encryption_with_customer_managed_key
         if enable_queue_purging is not None:
             self._values["enable_queue_purging"] = enable_queue_purging
+        if encryption_key is not None:
+            self._values["encryption_key"] = encryption_key
+        if encryption_key_props is not None:
+            self._values["encryption_key_props"] = encryption_key_props
         if existing_lambda_obj is not None:
             self._values["existing_lambda_obj"] = existing_lambda_obj
         if existing_queue_obj is not None:
@@ -374,6 +447,19 @@ class LambdaToSqsProps:
         result = self._values.get("deploy_vpc")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def enable_encryption_with_customer_managed_key(
+        self,
+    ) -> typing.Optional[builtins.bool]:
+        '''If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key.
+
+        This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps.
+
+        :default: - False if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        '''
+        result = self._values.get("enable_encryption_with_customer_managed_key")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def enable_queue_purging(self) -> typing.Optional[builtins.bool]:
         '''Whether to grant additional permissions to the Lambda function enabling it to purge the SQS queue.
@@ -383,6 +469,24 @@ class LambdaToSqsProps:
         result = self._values.get("enable_queue_purging")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
+        '''An optional, imported encryption key to encrypt the SQS Queue with.
+
+        :default: - None
+        '''
+        result = self._values.get("encryption_key")
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
+
+    @builtins.property
+    def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
+        '''Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS Queue with.
+
+        :default: - None
+        '''
+        result = self._values.get("encryption_key_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.KeyProps], result)
+
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
         '''Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
